#
# spec file for package iozone
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define src_version 3
%define src_release 444
Name:           iozone
Version:        %{src_version}.%{src_release}
Release:        2.4
Summary:        Filesystem Benchmark
License:        SUSE-Freeware and SUSE-Public-Domain and GPL-2.0+
Group:          System/Benchmark
Url:            http://www.iozone.org
Source0:        http://www.iozone.org/src/current/%{name}%{src_version}_%{src_release}.tgz
Source1:        http://www.iozone.org/docs/Iozone_License.txt
Source2:        https://www.gnu.org/licenses/gpl-2.0.txt
BuildRequires:  dos2unix
BuildRequires:  gcc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Filesystem benchmark tool. The benchmark tests file I/O performance for the following
operations: Read, write, re-read, re-write, read backwards, read strided,
fread, fwrite, random read, pread ,mmap, aio_read, aio_write.

%package doc
Summary:        Documentation how to use Iozone
Group:          Documentation/Man
BuildArch:      noarch

%description doc
This package contains the documentation for using and interpreting results of Iozone

%prep
%setup -q -n %{name}%{src_version}_%{src_release}

%build
# I: Program returns random data in a function
# E: iozone no-return-in-nonvoid-function libbif.c:175, 224, 256,343, 386,
# 402
# licence however does not permit us to patch sources, thus we need to
# ignore these failures
FLAGS="`echo %{optflags} | sed -e 's/\-Wall//g'`"
make %{?_smp_mflags} CFLAGS="$FLAGS -DHAVE_PREADV -DHAVE_PWRITEV" -C src/current linux

%install
install -D -p -m 0755 src/current/iozone %{buildroot}%{_bindir}/iozone
install -D -p -m 0755 src/current/fileop %{buildroot}%{_bindir}/fileop
install -D -p -m 0644 src/current/client_list %{buildroot}%{_datadir}/%{name}/client_list
install -D -p -m 0644 src/current/Generate_Graphs %{buildroot}%{_datadir}/%{name}/Generate_Graphs
install -D -p -m 0755 src/current/gengnuplot.sh %{buildroot}%{_datadir}/%{name}/gengnuplot.sh
install -D -p -m 0644 src/current/gnu3d.dem %{buildroot}%{_datadir}/%{name}/gnu3d.dem
install -D -p -m 0644 src/current/gnuplot.dem %{buildroot}%{_datadir}/%{name}/gnuplot.dem
install -D -p -m 0644 src/current/gnuplotps.dem %{buildroot}%{_datadir}/%{name}/gnuplotps.dem
install -D -p -m 0755 src/current/report.pl %{buildroot}%{_datadir}/%{name}/report.pl
install -D -p -m 0644 src/current/write_telemetry %{buildroot}%{_datadir}/%{name}/write_telemetry
install -D -p -m 0644 docs/iozone.1 %{buildroot}%{_mandir}/man1/iozone.1

chmod 644 src/current/Gnuplot.txt src/current/Changes.txt
dos2unix src/current/Gnuplot.txt
dos2unix %{buildroot}%{_datadir}/%{name}/report.pl
cp %{SOURCE1} Iozone_License.txt
cp %{SOURCE2} gpl-2.0.txt

%files
%defattr(-,root,root)
%doc src/current/Gnuplot.txt src/current/Changes.txt Iozone_License.txt gpl-2.0.txt
%{_bindir}/fileop
%{_bindir}/iozone
%{_datadir}/%{name}/
%{_mandir}/man1/iozone.1%{ext_man}

%files doc
%defattr(-,root,root)
%doc docs/*.pdf src/current/Changes.txt Iozone_License.txt gpl-2.0.txt

%changelog
* Mon Jul  4 2016 mpluskal@suse.com
- Filter -Wall from optflags to prevent post-build check failure:
  * no-return-in-nonvoid-function libbif.c:175, 224, 256,343, 386,
    402
  * license does not allow us to modify sources
  * reported issues seems harlmess in case of io benchmark
* Sat Jul  2 2016 mpluskal@suse.com
- Update to version 3_444:
  * Cleanup 64 bit compiles.
  * Code cleanup for all of the un-needed void * maddness.
  * Code cleanup for casting consistency and *&(^&*( compiler
    warnings !!!
  * Code cleanup for casting consistency
* Fri Feb  5 2016 mpluskal@suse.com
- Update to 3_434
  * Adding code from Alexey Skidanov. Pthread burst I/O.
- Build with optflags
- Enable PREADV and PWRITEV
- Minor spec file cleanups
- Fix typo in changelog
* Wed Jan 14 2015 mpluskal@suse.com
- Update license information
* Tue Jan 13 2015 mpluskal@suse.com
- update to version 3_430
  * Add two more characters to array my_port_num.
  * Adding -+b option for bursty operations.
- split documentation to separate package
* Wed Jul 30 2014 dsterba@suse.cz
- update to version 3_428
  * Minor bug fix for -J option (think time) in the thread_pread_test()
  * Add -+J option. Include think time (-j #) in throughput calculation
  * Add better handling of exit values.
  * Add new contributor to list.
  * Bug fix from Alp Aker:
  * Patch for a minor issue in IOzone's signal_handler() function
  * Improve consistency of Kbytes instead of kbytes, KBytes, kBytes...
  * Fix for 64 bit and touch_dedup.
  * Fix for 64 bit and gen_new_buf
  * Adjust formatting so fields don't run together.
- clean spec
* Mon Feb  4 2013 bahid@emc.com
- update to version 3_414 (3_283 in Benchmark:/Filesystem)
  * Add O_DIRECT for Windows
  * Add -+w dedup testing mode.
  * Make remaining non-dedup data unique.
  * Make non-dedupable more unique.
  * Bug fix for non-dedup.
  * Make random offsets unique, using Knuth shuffle.
  * free memory used for random offset uniqueness.
  * Make unique/random offsets 64bits.
  * Add fallback for random/unique.
  * Make non-dedup region more unique
  * Add -+y ## to set percentage of interior dedup.
  * Bug fixes for -+w and -+y
  * Minor fix for dedup
  * Adding -+C to set percent of dedupable within a file.
  * Add solaris to read sync O_RSYNC
  * Add space to avoid field output touching each other.
  * Add check for config file exceeding MAXSTREAMS.
  * Add new contributor's name.
  * Bug fix. rewrite_rec needed to fill entire buffer, or later stride read will fail.
  * Add ability for remote clients to return errors to the master and have the master display on output.
  * fix double reporting of client errors
  * Eliminate extra file descriptor in fwrite test.
  * bug fix for barray allocation in -T mode
  * Changes from Debian: Retry umount, add fileop for linux-sparc, and
  * fix column width in fileop for faster boxes.
  * Add O_DIRECT support to FreeBSD
  * Fix for defines in FreeBSD
  * Add IMON_SYNC to enable monitor scripts to be run sync.
  * Add directio() for Solaris
  * Add fixes for unresolved references in directio() for Solaris
  * Fix c++ style comment back to 'C' style comment.
  * Bug fix for check_filenames and large files
  * Replace tripple rand() calls with 64 bit Mersene twister.
  * Add read-only, external file, with no-verify. -+E
  * Permit -+E on dedup files.
  * Permit -+E on random read only testing, on existing file.
  * Add passing master listener's port to remote children if it is not HOST_LIST_PORT
  * Adding Dave Boone's notruncate option -+N
  * Bug fix for Dave's code.
  * Add multi -t ops. Fabrice
  * Added Li Qin's multi dedup set support. -+S #
  * Bug fix for -+S dedup_mseed needs to be an integer
  * Make -+S generate more uniqueness
  * Bug fix for -+S
  * Make umount/remount more robust, in the face of server errors.
  * Improve the help string for the -+S option.
  * Add new contributor name.
  * Add support for the programmable interdimensional timer.
  * Bug fix for PIT on remote clients.
  * Have children re-acquire get_resolution.
  * Bug fix for t_range addition.
  * Get rid of a warning. ( An invalid warning, but none the less )
  * Add more words to the usage warnings and license
  * Remove Ascii dependency for IBM's Z/OS that speaks EBCDIC.
  * Add support for SUA
  * Remove Sanity check so that SMB on Windows, under SUA, works
  * Cache the getaddrinfo call.
  * delete optimization.. bad...Cache the getaddrinfo call.
  * Change pit to use unsigned long longs
  * Add Linux processor affinity
  * Remove UDP usage
  * Increment protocol_version to catch incompat versions.
  * Fixup for new include needed by Solaris10
  * Patch for Mac errno
  * Patch for Mac printf's
  * Fix Josh's introduction of new Linux warnings.
  * Take sleep(1) out put path, deal with it in error/retry path
  * Add -+z latency histogram logging.
  * Format change for the -+z latency histogram logging.
  * Added -+O Op_rate control.
  * Close race condition with master closing socket to child async reader
  * Add "mygen" generation to the remote children protocol.
  * Set Listen(s,100) to Listen(s,MAXSTREAMS)
  * Move lable "again" to outside of cdebug.
  * More fixes for busted crap in Solaris !!!
  * AIX update. They now have errno.h
  * Need errno.h for FreeBSD
  * Need to include errno.h for Cygwin
  * Add SO_LINGER for master_listen and child_listen
  * Fix for linger addition
  * Make linger for all
  * Change sleep() calls, that help connect() to nanosleep() calls.
  * Fixup remainder for nanosleep()
  * Add code for pread/pwrite from Ben England (Redhat)
  * Add code for MDEBUG and CDEBUG from Bob England (Redhat)
  * Add code for building HPUX. Errno.h
  * Fixes for Windows (nanosleep doesn't always work )
  * Fixes for preadv and pwritev from RedHat (Ben Englanc)
  * Add warnings for default switch cases, and exit with value for unknowns.
  * Fix warnings from RedHat patches
  * Bug fix for getopt default case, with bad parameter handed in.
  * Adding thread_read_test and thread_write_test.
  * bug fix for re-write rec.
  * Mods for DragonFly support.
  * Add -+W to permit chid_skew.
  * Reduce CPU consumption in the op_rate control mechanism.
  * Increase buffer size for configuration lines.
  * Bug fix for clobbering of buffer. "tfile" needed to be bigger
  * Bug fix for using -m in combination with -+d
  * Bug fix: Improve consistency of use_thread in thread_fread and thread_fwrite
  * Compat fix: Move from using macosx to IOZ_macosx
  * Adding -+F flag for trunc before thread_write.
  * Bug fix for -+F flag.
* Thu Mar 29 2007 jblunck@suse.de
- initial package
